@@ -1,6 +1,6 @@
+use serde::{Serialize, Deserialize};
+use serde::de::IgnoredAny;
 use serde_json::Value;
-use serde::de::impls::IgnoredAny;
-
 
 #[derive(Serialize, Deserialize)]
 pub struct RawSectionOffset {
@@ -18,18 +18,18 @@ pub struct RawSection {
 #[derive(Serialize, Deserialize)]
 pub struct RawSourceMap {
     pub version: Option<u32>,
-    #[serde(skip_serializing_if="Option::is_none")]
+    #[serde(skip_serializing_if = "Option::is_none")]
     pub file: Option<Value>,
     pub sources: Option<Vec<String>>,
-    #[serde(rename="sourceRoot", skip_serializing_if="Option::is_none")]
+    #[serde(rename = "sourceRoot", skip_serializing_if = "Option::is_none")]
     pub source_root: Option<String>,
-    #[serde(rename="sourcesContent", skip_serializing_if="Option::is_none")]
+    #[serde(rename = "sourcesContent", skip_serializing_if = "Option::is_none")]
     pub sources_content: Option<Vec<Option<String>>>,
-    #[serde(skip_serializing_if="Option::is_none")]
+    #[serde(skip_serializing_if = "Option::is_none")]
     pub sections: Option<Vec<RawSection>>,
-    #[serde(skip_serializing_if="Option::is_none")]
+    #[serde(skip_serializing_if = "Option::is_none")]
     pub names: Option<Vec<Value>>,
-    #[serde(skip_serializing_if="Option::is_none")]
+    #[serde(skip_serializing_if = "Option::is_none")]
     pub mappings: Option<String>,
 }
 
@@ -38,9 +38,9 @@ pub struct MinimalRawSourceMap {
     pub version: Option<u32>,
     pub file: Option<IgnoredAny>,
     pub sources: Option<IgnoredAny>,
-    #[serde(rename="sourceRoot")]
+    #[serde(rename = "sourceRoot")]
     pub source_root: Option<IgnoredAny>,
-    #[serde(rename="sourcesContent")]
+    #[serde(rename = "sourcesContent")]
     pub sources_content: Option<IgnoredAny>,
     pub sections: Option<IgnoredAny>,
     pub names: Option<IgnoredAny>,
