@@ -1,10 +1,8 @@
-extern crate sourcemap;
-
 use std::io;
 use std::io::BufRead;
 
-use sourcemap::{decode_data_url, SourceMap, DecodedMap};
 use sourcemap::internals::StripHeaderReader;
+use sourcemap::{decode_data_url, DecodedMap, SourceMap};
 
 #[test]
 fn test_strip_header() {
@@ -58,12 +56,18 @@ fn test_basic_sourcemap() {
     }";
     let sm = SourceMap::from_reader(input).unwrap();
     let mut iter = sm.tokens().filter(|t| t.has_name());
-    assert_eq!(iter.next().unwrap().to_tuple(),
-               ("coolstuff.js", 0, 4, Some("x")));
-    assert_eq!(iter.next().unwrap().to_tuple(),
-               ("coolstuff.js", 1, 4, Some("x")));
-    assert_eq!(iter.next().unwrap().to_tuple(),
-               ("coolstuff.js", 2, 2, Some("alert")));
+    assert_eq!(
+        iter.next().unwrap().to_tuple(),
+        ("coolstuff.js", 0, 4, Some("x"))
+    );
+    assert_eq!(
+        iter.next().unwrap().to_tuple(),
+        ("coolstuff.js", 1, 4, Some("x"))
+    );
+    assert_eq!(
+        iter.next().unwrap().to_tuple(),
+        ("coolstuff.js", 2, 2, Some("alert"))
+    );
     assert!(iter.next().is_none());
 }
 
@@ -78,30 +82,42 @@ fn test_basic_sourcemap_with_root() {
     }";
     let sm = SourceMap::from_reader(input).unwrap();
     let mut iter = sm.tokens().filter(|t| t.has_name());
-    assert_eq!(iter.next().unwrap().to_tuple(),
-               ("x/coolstuff.js", 0, 4, Some("x")));
-    assert_eq!(iter.next().unwrap().to_tuple(),
-               ("x/coolstuff.js", 1, 4, Some("x")));
-    assert_eq!(iter.next().unwrap().to_tuple(),
-               ("x/coolstuff.js", 2, 2, Some("alert")));
+    assert_eq!(
+        iter.next().unwrap().to_tuple(),
+        ("x/coolstuff.js", 0, 4, Some("x"))
+    );
+    assert_eq!(
+        iter.next().unwrap().to_tuple(),
+        ("x/coolstuff.js", 1, 4, Some("x"))
+    );
+    assert_eq!(
+        iter.next().unwrap().to_tuple(),
+        ("x/coolstuff.js", 2, 2, Some("alert"))
+    );
     assert!(iter.next().is_none());
 }
 
 #[test]
 fn test_sourcemap_data_url() {
     let url = "data:application/json;base64,\
-         eyJ2ZXJzaW9uIjozLCJzb3VyY2VzIjpbImNvb2xzdHVmZi5qcyJdLCJzb3VyY2VSb290I\
-         joieCIsIm5hbWVzIjpbIngiLCJhbGVydCJdLCJtYXBwaW5ncyI6IkFBQUEsR0FBSUEsR0\
-         FBSSxFQUNSLElBQUlBLEdBQUssRUFBRyxDQUNWQyxNQUFNIn0=";
+               eyJ2ZXJzaW9uIjozLCJzb3VyY2VzIjpbImNvb2xzdHVmZi5qcyJdLCJzb3VyY2VSb290I\
+               joieCIsIm5hbWVzIjpbIngiLCJhbGVydCJdLCJtYXBwaW5ncyI6IkFBQUEsR0FBSUEsR0\
+               FBSSxFQUNSLElBQUlBLEdBQUssRUFBRyxDQUNWQyxNQUFNIn0=";
     match decode_data_url(url).unwrap() {
         DecodedMap::Regular(sm) => {
             let mut iter = sm.tokens().filter(|t| t.has_name());
-            assert_eq!(iter.next().unwrap().to_tuple(),
-                       ("x/coolstuff.js", 0, 4, Some("x")));
-            assert_eq!(iter.next().unwrap().to_tuple(),
-                       ("x/coolstuff.js", 1, 4, Some("x")));
-            assert_eq!(iter.next().unwrap().to_tuple(),
-                       ("x/coolstuff.js", 2, 2, Some("alert")));
+            assert_eq!(
+                iter.next().unwrap().to_tuple(),
+                ("x/coolstuff.js", 0, 4, Some("x"))
+            );
+            assert_eq!(
+                iter.next().unwrap().to_tuple(),
+                ("x/coolstuff.js", 1, 4, Some("x"))
+            );
+            assert_eq!(
+                iter.next().unwrap().to_tuple(),
+                ("x/coolstuff.js", 2, 2, Some("alert"))
+            );
             assert!(iter.next().is_none());
         }
         _ => {
